; RTL - A Formal Theory of Register-Transfer Logic and Computer Arithmetic
; Copyright (C) 1995-2013 Advanced Mirco Devices, Inc.
;
; Contact:
;   David Russinoff
;   1106 W 9th St., Austin, TX 78703
;   http://www.russsinoff.com/
;
; See license file books/rtl/rel11/license.txt.
;
; Author: David M. Russinoff (david@russinoff.com)

(in-package "RTL")

(include-book "verify-guards")

(include-book "./add")

(include-book "./mult")

(include-book "./util")

(include-book "./srt")

(include-book "./gl")

(include-book "./basic")

(include-book "./bits")

(include-book "./log")

(include-book "./float")

(include-book "./reps")

(include-book "./round")

(include-book "./sqrt")

(include-book "./div")

(include-book "./excps")

(include-book "./rac")
